/[Apache-SVN]/maven/continuum/trunk/continuum-core-it/continuum_cli.py
ViewVC logotype

Diff of /maven/continuum/trunk/continuum-core-it/continuum_cli.py

Parent Directory Parent Directory | Revision Log Revision Log | View Patch Patch

--- maven/continuum/trunk/continuum-core-it/continuum_cli.py	2005/05/02 10:55:17	165618
+++ maven/continuum/trunk/continuum-core-it/continuum_cli.py	2005/05/02 11:49:52	165619
@@ -38,14 +38,23 @@ class ContinuumXmlRpcClient(cli.cli):
 
         print "Version 1.0"
 
-    def do_addProject(self, args):
-        """Add a Continuum project.
-        Use this command to add a project to Continuum."""
+    def do_addMavenTwoProject(self, args):
+        """Add a Maven 2.x project."""
 
-        projectId = continuum.addProjectFromUrl( args[0], args[1] )
+        projectId = continuum.addMavenTwoProject( args[0] )
 
         print "Added project, id: " + projectId
 
+    def do_addMavenOneProject(self, args):
+        """Add a Maven 1.x project."""
+
+        projectId = continuum.addMavenOneProject( args[0] )
+
+        print "Added project, id: " + projectId
+
+    # TODO: addAntProject
+    # TODO: addShellProject
+
     def do_showProject(self, args):
         """Shows Continuum project.
         Use this command to show the details of a Continuum project."""

 

infrastructure at apache.org
ViewVC Help
Powered by ViewVC 1.1.26